@@ -169,13 +169,12 @@ where
 
             tok!("url") => return Ok(Value::Url(self.parse()?)),
 
-            Token::Function { value, .. } => {
-                if &*value.to_ascii_lowercase() == "url" || &*value.to_ascii_lowercase() == "src" {
-                    return Ok(Value::Url(self.parse()?));
-                }
-
-                return Ok(Value::Function(self.parse()?));
-            }
+            Token::Function { value, .. } => match &*value.to_ascii_lowercase() {
+                "url" | "src" => return Ok(Value::Url(self.parse()?)),
+                "rgb" | "rgba" | "hsl" | "hsla" | "hwb" | "lab" | "lch" | "oklab" | "oklch"
+                | "color" => return Ok(Value::Color(self.parse()?)),
+                _ => return Ok(Value::Function(self.parse()?)),
+            },
 
             tok!("percentage") => return Ok(Value::Percentage(self.parse()?)),
 
@@ -1084,6 +1083,30 @@ where
     }
 }
 
+impl<I> Parse<Color> for Parser<I>
+where
+    I: ParserInput,
+{
+    fn parse(&mut self) -> PResult<Color> {
+        let span = self.input.cur_span()?;
+
+        if !is_one_of!(self, "#", "function") {
+            return Err(Error::new(
+                span,
+                ErrorKind::Expected("hash or function token"),
+            ));
+        }
+
+        match cur!(self) {
+            tok!("#") => Ok(Color::HexColor(self.parse()?)),
+            tok!("function") => Ok(Color::Function(self.parse()?)),
+            _ => {
+                unreachable!()
+            }
+        }
+    }
+}
+
 impl<I> Parse<Percentage> for Parser<I>
 where
     I: ParserInput,
