@@ -314,6 +314,8 @@ impl Visit for SpanVisualizer<'_> {
 
     mtd!(AnPlusB, visit_an_plus_b);
 
+    mtd!(AnPlusBNotation, visit_an_plus_b_notation);
+
     mtd!(Delimiter, visit_delimiter);
 
     mtd!(SimpleBlock, visit_simple_block);
@@ -336,8 +338,6 @@ impl Visit for SpanVisualizer<'_> {
 
     mtd!(ImportantFlag, visit_important_flag);
 
-    mtd!(Nth, visit_nth);
-
     mtd!(Rule, visit_rule);
 
     mtd!(Str, visit_str);
